DropBox
=======

Settings
--------


``DROPBOX_OAUTH2_TOKEN``

Your DropBox token, if you haven't follow this `guide step`_.

``DROPBOX_ROOT_PATH``

Allow to jail your storage to a defined directory.


.. _`guide step`: https://www.dropbox.com/developers/documentation/python#tutorial
